package org.fremo.fredl.test;

import java.util.concurrent.TimeUnit;

import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.htmlunit.HtmlUnitDriver;
import org.openqa.selenium.support.ui.WebDriverWait;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

public class BasicTest {
    private WebDriver driver;
    private WebDriverWait wait;
    private int timeoutInSeconds = 20;
    String URL = "https://0.fredldev.fremo-net.eu";

    @BeforeClass
    public void testSetUp() {
        driver = new HtmlUnitDriver(true);
        wait = new WebDriverWait(driver, timeoutInSeconds);
        FredlTestHelper.setUp(driver);
    }

    @AfterClass
    public void tearDown() {
        driver.quit();
    }

    @Test
    public void verifyFredlPageTitle() {
        System.out.println("----------------------------- verifyFredlPageTitle ----------------------------------");
        driver.navigate().to(URL);
        String getTitle = driver.getTitle();
        System.out.println("Page title: " + getTitle);
        Assert.assertEquals(getTitle, "FREDL");
    }

    @Test (dependsOnMethods={"verifyFredlPageTitle"})
    public void verifyLoginAsSystemUser() {
        System.out.println("----------------------------- verifyLoginAsSystemUser ----------------------------------");
        driver.navigate().to(URL);
        System.out.println("Navigate to: " + URL);

        if (FredlTestHelper.elementExistsById("privacy-cookie-statement")) {
            System.out.println("Cookies consent page is shown");
            WebElement consentButton = driver.findElement(By.id("opt-in-button-allow"));
            consentButton.click();
        }

        WebElement loginButton = wait.until(ExpectedConditions.elementToBeClickable(By.name("doLogin")));

        String scaleInfo = driver.findElement(By.xpath("//table[@class='loginall']/tbody/tr/td/div")).getText();
        System.out.println("Scale: " + scaleInfo);

        driver.findElement(By.xpath("//input[@name='login']")).sendKeys("system");
        driver.findElement(By.xpath("//input[@name='password']")).sendKeys("system");
        loginButton.click();

        String expectedTitle = "FreDL";
        wait.until(ExpectedConditions.titleIs(expectedTitle));

        // FredlTestHelper.printPageSource(driver);

        driver.switchTo().defaultContent();
        String frameObenName = "oben";
        wait.until(ExpectedConditions.frameToBeAvailableAndSwitchToIt(frameObenName));

        // FredlTestHelper.printPageSource(driver);

        String versionInfo = driver.findElement(By.xpath("//table[1]/tbody/tr/td[1]/b")).getText();
        String userInfo = driver.findElement(By.xpath("//table[1]/tbody/tr/td[3]")).getText();
        String expectedUserInfo = "Benutzer: FREDL System (Syste)";
        System.out.println("Version info found: " + versionInfo);
        System.out.println("User info found: " + userInfo);
        Assert.assertEquals(userInfo, expectedUserInfo);

        driver.switchTo().defaultContent();
        String frameRechtsName = "rechts";
        driver.switchTo().frame(frameRechtsName);

        // FredlTestHelper.printPageSource(driver);

        String welcomeMessage = driver.findElement(By.xpath("//body/h1")).getText();
        String expectedWelcomeMessage = "Willkommen bei FreDL";
        System.out.println("Welcome message is: " + welcomeMessage);
        Assert.assertEquals(welcomeMessage, expectedWelcomeMessage);

        // we leave our tests always with having the driver located to the top frame
        driver.switchTo().parentFrame();
    }

    @Test (dependsOnMethods={"verifyLoginAsSystemUser"})
    public void verifyExistenceOfMainMenuButtons() {
        System.out.println("----------------------------- verifyExistenceOfMainMenuButtons ----------------------------------");
        driver.navigate().refresh();
        System.out.println("Current URL=" + driver.getCurrentUrl());
        //FredlTestHelper.printPageSource();
        wait.until(ExpectedConditions.frameToBeAvailableAndSwitchToIt("oben"));
        // Verify existence of menu buttons
        Assert.assertEquals(FredlTestHelper.elementExistsById("admin-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("loco-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("cargo-cars-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("passenger-cars-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("module-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("equip-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("meeting-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("fileman-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("calendar-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("idman-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("lola-menu-button"), true);
        Assert.assertEquals(FredlTestHelper.elementExistsById("logout-menu-button"), true);
        driver.switchTo().parentFrame();
    }

    @Test (dependsOnMethods={"verifyExistenceOfMainMenuButtons"})
    public void verifyLogout() {
        System.out.println("----------------------------- verifyLogout ----------------------------------");
        wait.until(ExpectedConditions.frameToBeAvailableAndSwitchToIt("oben"));
        driver.findElement(By.id("logout-menu-button")).click();
        Assert.assertEquals(FredlTestHelper.elementExistsByXpath("//input[@name='doLogin']"), true);
    }
}
