package org.fremo.fredl.test;

import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.htmlunit.HtmlUnitDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

import java.util.concurrent.TimeUnit;

public class StartInstaller {
    private WebDriver driver;
    private WebDriverWait wait;
    private int implicitTimeoutMilliseconds = 3000;
    private int timeoutInSeconds = 20;
    String URL = "https://0.fredldev.fremo-net.eu";

    @BeforeClass
    public void testSetUp() {

        driver = new HtmlUnitDriver(true);
        wait = new WebDriverWait(driver, timeoutInSeconds);
        driver.manage().timeouts().implicitlyWait(implicitTimeoutMilliseconds, TimeUnit.MILLISECONDS);
        FredlTestHelper.setUp(driver);
    }

    @AfterClass
    public void tearDown() {
        driver.quit();
    }

    @Test
    public void startInstaller() {
        driver.navigate().to(URL);

        FredlTestHelper.skipConsentCookiePage();

        String getTitle = driver.getTitle();
        System.out.println("Page title: " + getTitle);

        // FredlTestHelper.printPageSource();

        if (FredlTestHelper.elementExistsByXpath("//table[@class='loginall']")) {
            // Login page shown, thus we do not need to start the installer
            return;
        }
        Assert.assertEquals(getTitle, "FreDL");
        WebElement installerLink = driver.findElement(By.xpath("//a[@href='install.php']"));
        String expectedInstallerLinkText = "start the installer";
        Assert.assertEquals(installerLink.getText(), expectedInstallerLinkText);
        installerLink.click();

        // FredlTestHelper.printPageSource();

        String expectedAppLinkText = "Go to application";
        WebElement appLink = wait.until(ExpectedConditions.elementToBeClickable(By.xpath("//a[@href='/']")));
        Assert.assertEquals(appLink.getText(), expectedAppLinkText);
        appLink.click();
    }

}
